@@ -40,7 +40,39 @@ class MinosMessageException(MinosException):
 
 
 class MinosConfigException(MinosException):
-    pass
+    """Base config exception."""
+
+
+class MinosConfigDefaultAlreadySetException(MinosConfigException):
+    """Exception to be raised when some config is already set as default."""
+
+
+class MinosRepositoryException(MinosException):
+    """Base repository exception."""
+
+
+class MinosRepositoryAggregateNotFoundException(MinosRepositoryException):
+    """Exception to be raised when some aggregate is not found on the repository."""
+
+
+class MinosRepositoryDeletedAggregateException(MinosRepositoryException):
+    """Exception to be raised when some aggregate is already deleted from the repository."""
+
+
+class MinosRepositoryManuallySetAggregateIdException(MinosRepositoryException):
+    """Exception to be raised when some aggregate is trying to be created with a manually set id."""
+
+
+class MinosRepositoryManuallySetAggregateVersionException(MinosRepositoryException):
+    """Exception to be raised when some aggregate is trying to be created with a manually set version."""
+
+
+class MinosRepositoryUnknownActionException(MinosRepositoryException):
+    """Exception to be raised when some entry tries to perform an unknown action."""
+
+
+class MinosRepositoryNonProvidedException(MinosRepositoryException):
+    """Exception to be raised when a repository is needed but none is set."""
 
 
 class MinosModelException(MinosException):
